Package: CDMConnector
Title: Connect to an OMOP Common Data Model
Version: 2.5.1
Authors@R: c(
    person("Adam", "Black", , "ablack3@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-5576-8701")),
    person("Artem", "Gorbachev", , "artem.gorbachev@odysseusinc.com", role = "aut"),
    person("Edward", "Burn", , "edward.burn@ndorms.ox.ac.uk", role = "aut"),
    person("Marti", "Catala Sabate", , "marti.catalasabate@ndorms.ox.ac.uk", role = "aut"),
    person("Ioanna", "Nika", , "i.nika@darwin-eu.org", role = "aut")
  )
Description: Provides tools for working with observational health data in the 
  Observational Medical Outcomes Partnership (OMOP) Common Data Model format with a pipe friendly syntax.
  Common data model database table references are stored in a single compound object along with metadata.
License: Apache License (>= 2)
URL: https://darwin-eu.github.io/CDMConnector/,
        https://github.com/darwin-eu/CDMConnector
BugReports: https://github.com/darwin-eu/CDMConnector/issues
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.1.0)
Imports: httr, dplyr, dbplyr (>= 2.5.0), DBI (>= 0.3.0), checkmate,
        cli, purrr, rlang, tidyselect, glue, methods, withr, lifecycle,
        stringr, stringi, generics, tidyr, jsonlite, readr,
        omopgenerics (>= 1.2.0)
Suggests: SqlRender, CirceR, rJava, covr, knitr, rmarkdown, duckdb,
        RSQLite, RPostgres, DatabaseConnector, odbc, ggplot2,
        bigrquery, lubridate, clock, tibble, testthat (>= 3.0.0), pool,
        snakecase, digest, rstudioapi, uuid
Enhances: arrow
Config/testthat/edition: 3
Config/testthat/parallel: false
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-02 01:09:56 UTC; ablack
Author: Adam Black [aut, cre] (ORCID: <https://orcid.org/0000-0001-5576-8701>),
  Artem Gorbachev [aut],
  Edward Burn [aut],
  Marti Catala Sabate [aut],
  Ioanna Nika [aut]
Maintainer: Adam Black <ablack3@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-03 05:10:29 UTC
Built: R 4.4.3; ; 2026-04-08 00:14:30 UTC; unix
