# Generated by roxygen2: do not edit by hand

S3method(bind,cdm_table)
S3method(cdmDisconnect,db_cdm)
S3method(cdmTableFromSource,db_cdm)
S3method(compute,db_cdm)
S3method(dbplyr_edition,BigQueryConnection)
S3method(dropSourceTable,db_cdm)
S3method(dropTable,db_cdm)
S3method(insertCdmTo,db_cdm)
S3method(insertFromSource,db_cdm)
S3method(insertTable,db_cdm)
S3method(listSourceTables,db_cdm)
S3method(readSourceTable,db_cdm)
S3method(summary,db_cdm)
S3method(tbl,db_cdm)
export("%>%")
export(appendPermanent)
export(asDate)
export(attrition)
export(benchmarkCDMConnector)
export(bind)
export(cdmCommentContents)
export(cdmCon)
export(cdmDisconnect)
export(cdmFlatten)
export(cdmFromCohortSet)
export(cdmFromCon)
export(cdmFromTables)
export(cdmName)
export(cdmReference)
export(cdmSample)
export(cdmSelect)
export(cdmSubset)
export(cdmSubsetCohort)
export(cdmTrimVocabulary)
export(cdmVersion)
export(cdmWriteSchema)
export(cohdSimilarConcepts)
export(cohortCodelist)
export(cohortCount)
export(compute)
export(computeDataHashByTable)
export(computeQuery)
export(copyCdmTo)
export(dateadd)
export(datediff)
export(datepart)
export(dbSource)
export(dbms)
export(downloadEunomiaData)
export(dropSourceTable)
export(dropTable)
export(eunomiaDir)
export(eunomiaIsAvailable)
export(exampleDatasets)
export(generateCohortSet)
export(generateConceptCohortSet)
export(inSchema)
export(insertCdmTo)
export(insertTable)
export(listSourceTables)
export(listTables)
export(newCohortTable)
export(readCohortSet)
export(readSourceTable)
export(recordCohortAttrition)
export(requireEunomia)
export(settings)
export(snapshot)
export(sourceType)
export(summariseQuantile)
export(summariseQuantile2)
export(tblGroup)
export(uniqueTableName)
export(version)
import(DBI)
import(omopgenerics)
importFrom(dbplyr,dbplyr_edition)
importFrom(dplyr,"%>%")
importFrom(dplyr,all_of)
importFrom(dplyr,compute)
importFrom(dplyr,contains)
importFrom(dplyr,ends_with)
importFrom(dplyr,matches)
importFrom(dplyr,starts_with)
importFrom(dplyr,tbl)
importFrom(dplyr,tibble)
importFrom(generics,compile)
importFrom(httr,GET)
importFrom(httr,content)
importFrom(httr,http_error)
importFrom(httr,status_code)
importFrom(httr,timeout)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,read_json)
importFrom(methods,is)
importFrom(omopgenerics,attrition)
importFrom(omopgenerics,bind)
importFrom(omopgenerics,cdmDisconnect)
importFrom(omopgenerics,cdmFromTables)
importFrom(omopgenerics,cdmName)
importFrom(omopgenerics,cdmReference)
importFrom(omopgenerics,cdmSelect)
importFrom(omopgenerics,cdmTableFromSource)
importFrom(omopgenerics,cdmVersion)
importFrom(omopgenerics,cohortCodelist)
importFrom(omopgenerics,cohortCount)
importFrom(omopgenerics,dropSourceTable)
importFrom(omopgenerics,dropTable)
importFrom(omopgenerics,insertCdmTo)
importFrom(omopgenerics,insertFromSource)
importFrom(omopgenerics,insertTable)
importFrom(omopgenerics,listSourceTables)
importFrom(omopgenerics,newCohortTable)
importFrom(omopgenerics,readSourceTable)
importFrom(omopgenerics,recordCohortAttrition)
importFrom(omopgenerics,settings)
importFrom(omopgenerics,sourceType)
importFrom(omopgenerics,uniqueTableName)
importFrom(purrr,"%||%")
importFrom(rlang,"!!")
importFrom(rlang,"%||%")
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(stats,aggregate)
importFrom(stats,rpois)
importFrom(tidyselect,ends_with)
importFrom(tidyselect,matches)
importFrom(tidyselect,starts_with)
importFrom(utils,download.file)
importFrom(utils,head)
importMethodsFrom(DBI,dbConnect)
